==> haskell-enummapset-0.7.3.0-131.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-enummapset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 enummapset
version:              0.7.3.0
visibility:           public
id:                   enummapset-0.7.3.0-2dh8JkjpSa6IrHg1zYWgj5
key:                  enummapset-0.7.3.0-2dh8JkjpSa6IrHg1zYWgj5
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Michal Terepeta and others
homepage:             https://github.com/Mikolaj/enummapset
synopsis:             IntMap and IntSet with Enum keys/elements.
description:
    This package contains simple wrappers around '\''Data.IntMap'\'' and
    '\''Data.IntSet'\'' with '\''Enum'\'' keys and elements respectively.
    Especially useful for '\''Int'\''s wrapped with `newtype`.

category:             Data Structures
abi:                  cfd33093ab2135a8a0b964d4773cc8ff
exposed:              True
exposed-modules:
    Data.EnumMap Data.EnumMap.Lazy Data.EnumMap.Strict Data.EnumSet

hidden-modules:       Data.EnumMap.Base
import-dirs:          /usr/lib/ghc-9.6.6/site-local/enummapset-0.7.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/enummapset-0.7.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/enummapset-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enummapset
hs-libraries:         HSenummapset-0.7.3.0-2dh8JkjpSa6IrHg1zYWgj5
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1

haddock-interfaces:   /usr/share/doc/haskell-enummapset/html/enummapset.haddock
haddock-html:         /usr/share/doc/haskell-enummapset/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enummapset-0.7.3.0-132-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-enummapset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 enummapset
version:              0.7.3.0
visibility:           public
id:                   enummapset-0.7.3.0-9IIdu7sihJJI8JszAnk4X4
key:                  enummapset-0.7.3.0-9IIdu7sihJJI8JszAnk4X4
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Michal Terepeta and others
homepage:             https://github.com/Mikolaj/enummapset
synopsis:             IntMap and IntSet with Enum keys/elements.
description:
    This package contains simple wrappers around '\''Data.IntMap'\'' and
    '\''Data.IntSet'\'' with '\''Enum'\'' keys and elements respectively.
    Especially useful for '\''Int'\''s wrapped with `newtype`.

category:             Data Structures
abi:                  ece3fd118f05fa4b98931fa257f3146a
exposed:              True
exposed-modules:
    Data.EnumMap Data.EnumMap.Lazy Data.EnumMap.Strict Data.EnumSet

hidden-modules:       Data.EnumMap.Base
import-dirs:          /usr/lib/ghc-9.6.6/site-local/enummapset-0.7.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/enummapset-0.7.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/enummapset-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enummapset
hs-libraries:         HSenummapset-0.7.3.0-9IIdu7sihJJI8JszAnk4X4
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1

haddock-interfaces:   /usr/share/doc/haskell-enummapset/html/enummapset.haddock
haddock-html:         /usr/share/doc/haskell-enummapset/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
